@@ -2,7 +2,7 @@ package Dist::Zilla::Plugin::GitHubREADME::Badge;
 
 use strict;
 use 5.008_005;
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use Moose;
 use namespace::autoclean;
@@ -52,6 +52,12 @@ sub after_build {
             push @badges, "[![Kwalitee status](http://cpants.cpanauthors.org/dist/$distname.png)](http://cpants.charsbar.org/dist/overview/$distname)";
         } elsif ($badge eq 'issues') {
             push @badges, "[![GitHub issues](https://img.shields.io/github/issues/$user_name/$repository_name.svg)](https://github.com/$user_name/$repository_name/issues)";
+        } elsif ($badge eq 'github_tag') {
+            push @badges, "[![GitHub tag](https://img.shields.io/github/tag/$user_name/$repository_name.svg)]()";
+        } elsif ($badge eq 'license') {
+            push @badges, "[![Cpan license](https://img.shields.io/cpan/l/$distname.svg)]()";
+        } elsif ($badge eq 'version') {
+            push @badges, "[![Cpan version](https://img.shields.io/cpan/v/$distname.svg)]()";
         }
     }
 
@@ -85,6 +91,9 @@ Dist::Zilla::Plugin::GitHubREADME::Badge - Dist::Zilla - add badges to github RE
     badges = gitter
     badges = cpants
     badges = issues
+    badges = github_tag
+    badges = license
+    badges = version
     place = bottom
 
 =head1 DESCRIPTION
